import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_user/ocg_user.dart';
import 'package:ocg_user/src/bloc/user_contact/event.dart';
import 'package:ocg_user/src/bloc/user_contact/state.dart';
import 'package:ocg_user/src/repository/user.dart';

class UserContactBloc extends Bloc<UserContactEvent, UserContactState> {
  final UserRepository userRepository;
  UserContactBloc(this.userRepository) : super(UserContactLoadingState());

  @override
  Stream<UserContactState> mapEventToState(UserContactEvent event) async* {
    if (event is UserContactSyncEvent) {
      AppResponse<List<ContactRequest>> contactResponse =
          await userRepository.fetchContacts();
      if (contactResponse.isSuccess) {
        AppResponse<bool> syncResponse =
            await userRepository.addContacts(contactResponse.data);
        if (syncResponse.isSuccess) {
          yield UserContactSyncedState();
        } else {
          yield UserContactErrorState(syncResponse.error);
        }
      } else {
        yield UserContactErrorState(contactResponse.error);
      }
    }
    if (event is UserContactFetchEvent) {
      AppResponse<List<ContactRequest>> response =
          await userRepository.fetchContacts();
      if (response.isSuccess) {
        yield UserContactLoadedState(response.data);
      } else {
        yield UserContactErrorState(response.error.toString());
      }
    }
  }
}
